==> openshift-model-operatorhub-5.8.1-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/CatalogSourceStatusBuilder.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class CatalogSourceStatusBuilder extends io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatusFluentImpl<io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatus,io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatusBuilder>{
  public CatalogSourceStatusBuilder() {
    this(false);
  }
  public CatalogSourceStatusBuilder(java.lang.Boolean validationEnabled) {
    this(new CatalogSourceStatus(), validationEnabled);
  }
  public CatalogSourceStatusBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public CatalogSourceStatusBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatusFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new CatalogSourceStatus(), validationEnabled);
  }
  public CatalogSourceStatusBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatusFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatus instance) {
    this(fluent, instance, false);
  }
  public CatalogSourceStatusBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatusFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withConfigMapReference(instance.getConfigMapReference()); 
    fluent.withConnectionState(instance.getConnectionState()); 
    fluent.withLatestImageRegistryPoll(instance.getLatestImageRegistryPoll()); 
    fluent.withMessage(instance.getMessage()); 
    fluent.withReason(instance.getReason()); 
    fluent.withRegistryService(instance.getRegistryService()); 
    this.validationEnabled = validationEnabled; 
  }
  public CatalogSourceStatusBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatus instance) {
    this(instance,false);
  }
  public CatalogSourceStatusBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withConfigMapReference(instance.getConfigMapReference()); 
    this.withConnectionState(instance.getConnectionState()); 
    this.withLatestImageRegistryPoll(instance.getLatestImageRegistryPoll()); 
    this.withMessage(instance.getMessage()); 
    this.withReason(instance.getReason()); 
    this.withRegistryService(instance.getRegistryService()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatusFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatus build() {
    CatalogSourceStatus buildable = new CatalogSourceStatus(fluent.getConfigMapReference(),fluent.getConnectionState(),fluent.getLatestImageRegistryPoll(),fluent.getMessage(),fluent.getReason(),fluent.getRegistryService());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CatalogSourceStatusBuilder that = (CatalogSourceStatusBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-operatorhub-5.10.1-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/CatalogSourceStatusBuilder.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class CatalogSourceStatusBuilder extends io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatusFluentImpl<io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatus,io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatusBuilder>{
  public CatalogSourceStatusBuilder() {
    this(false);
  }
  public CatalogSourceStatusBuilder(java.lang.Boolean validationEnabled) {
    this(new CatalogSourceStatus(), validationEnabled);
  }
  public CatalogSourceStatusBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public CatalogSourceStatusBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatusFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new CatalogSourceStatus(), validationEnabled);
  }
  public CatalogSourceStatusBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatusFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatus instance) {
    this(fluent, instance, false);
  }
  public CatalogSourceStatusBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatusFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withConfigMapReference(instance.getConfigMapReference()); 
    fluent.withConnectionState(instance.getConnectionState()); 
    fluent.withLatestImageRegistryPoll(instance.getLatestImageRegistryPoll()); 
    fluent.withMessage(instance.getMessage()); 
    fluent.withReason(instance.getReason()); 
    fluent.withRegistryService(instance.getRegistryService()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public CatalogSourceStatusBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatus instance) {
    this(instance,false);
  }
  public CatalogSourceStatusBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withConfigMapReference(instance.getConfigMapReference()); 
    this.withConnectionState(instance.getConnectionState()); 
    this.withLatestImageRegistryPoll(instance.getLatestImageRegistryPoll()); 
    this.withMessage(instance.getMessage()); 
    this.withReason(instance.getReason()); 
    this.withRegistryService(instance.getRegistryService()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatusFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.CatalogSourceStatus build() {
    CatalogSourceStatus buildable = new CatalogSourceStatus(fluent.getConfigMapReference(),fluent.getConnectionState(),fluent.getLatestImageRegistryPoll(),fluent.getMessage(),fluent.getReason(),fluent.getRegistryService());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CatalogSourceStatusBuilder that = (CatalogSourceStatusBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
